@@ -2,6 +2,7 @@ use crate::{SecureChannelTrustInfo, TrustPolicy};
 use ockam_core::{async_trait, compat::boxed::Box};
 use ockam_core::{AsyncTryClone, Result};
 
+#[derive(AsyncTryClone)]
 pub struct AnyTrustPolicy<F: TrustPolicy, S: TrustPolicy> {
     // TODO: Extend for more than 2 policies
     first: F,
@@ -14,16 +15,6 @@ impl<F: TrustPolicy, S: TrustPolicy> AnyTrustPolicy<F, S> {
     }
 }
 
-#[async_trait]
-impl<F: TrustPolicy, S: TrustPolicy> AsyncTryClone for AnyTrustPolicy<F, S> {
-    async fn async_try_clone(&self) -> Result<Self> {
-        Ok(Self {
-            first: self.first.async_try_clone().await?,
-            second: self.second.async_try_clone().await?,
-        })
-    }
-}
-
 #[async_trait]
 impl<F: TrustPolicy, S: TrustPolicy> TrustPolicy for AnyTrustPolicy<F, S> {
     async fn check(&self, trust_info: &SecureChannelTrustInfo) -> Result<bool> {
