@@ -1,14 +1,13 @@
 //! Entity is an abstraction over Profiles and Vaults, easing the use of these primitives in
 //! authentication and authorization APIs.
-#![deny(
-  // prevented by big_array
-  //  missing_docs,
+#![deny(unsafe_code)]
+#![warn(
+    // prevented by big_array
+    //  missing_docs,
     trivial_casts,
     trivial_numeric_casts,
-    unsafe_code,
     unused_import_braces,
-    unused_qualifications,
-    warnings
+    unused_qualifications
 )]
 #![cfg_attr(not(feature = "std"), no_std)]
 
@@ -222,11 +221,11 @@ mod test {
 
     #[ockam_node_test_attribute::node_test]
     async fn async_tests(ctx: &mut Context) -> Result<()> {
-        let alice_vault = Vault::create(&ctx).await.expect("failed to create vault");
-        let bob_vault = Vault::create(&ctx).await.expect("failed to create vault");
+        let alice_vault = Vault::create(ctx).await.expect("failed to create vault");
+        let bob_vault = Vault::create(ctx).await.expect("failed to create vault");
 
-        let entity_alice = Entity::create(&ctx, &alice_vault).await?;
-        let entity_bob = Entity::create(&ctx, &bob_vault).await?;
+        let entity_alice = Entity::create(ctx, &alice_vault).await?;
+        let entity_bob = Entity::create(ctx, &bob_vault).await?;
 
         let mut alice = entity_alice.current_profile().await.unwrap().unwrap();
         let mut bob = entity_bob.current_profile().await.unwrap().unwrap();
