@@ -27,21 +27,12 @@ use ockam_core::{Result, Route};
 use ockam_node::Handle;
 use ockam_vault::{PublicKey, Secret};
 
+#[derive(AsyncTryClone)]
 pub struct Profile {
     id: ProfileIdentifier,
     handle: Handle,
 }
 
-#[async_trait]
-impl AsyncTryClone for Profile {
-    async fn async_try_clone(&self) -> Result<Self> {
-        Ok(Self {
-            id: self.id.clone(),
-            handle: self.handle.async_try_clone().await?,
-        })
-    }
-}
-
 impl Entity {
     async fn from_profile(p: &Profile) -> Result<Entity> {
         Ok(Entity::new(
